IntoFieldError

Trait IntoFieldError 

pub trait IntoFieldError<S = DefaultScalarValue> {
    // Required method
    fn into_field_error(self) -> FieldError<S>;
}
Custom error handling trait to enable error types other than FieldError to be specified as return value.

Any custom error type should implement this trait to convert itself into a FieldError.

Required Methods

fn into_field_error(self) -> FieldError<S>

Performs the custom conversion into a FieldError.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, S> IntoFieldError<S> for &'a str

Source

impl<'a, S> IntoFieldError<S> for Cow<'a, str>

Source

impl<S> IntoFieldError<S> for Infallible

Source

impl<S> IntoFieldError<S> for String

Implementors